@@ -21,7 +21,7 @@ except ImportError:
     pass
 
 from .perms import REDIRECT_FIELD_NAME, is_valid
-from .utils import (bcrypt, AUTH_SESSION_NAME, LazyUser, Token, get_user_hmac,
+from .utils import (bcrypt, LazyUser, Token,
     auth_loader, split_hash, hash_sha256, hash_sha512, hash_bcrypt)
 
 
@@ -194,6 +194,8 @@ class Auth(object):
         'reset_password_view': 'auth_reset_password.html',
         'email_reset_view': 'auth_email_reset_password.html',
     }
+
+    LazyUser = LazyUser
     
     def __init__(self, settings, db, User, app=None):
         self.db = db
@@ -257,7 +259,7 @@ class Auth(object):
             self.get_user(request)
     
     def get_user(self, request):
-        request.__class__.user = LazyUser(self.db, self.User)
+        request.__class__.user = self.LazyUser(self.db, self.User)
     
     def get_urls(self):
         urls = [
@@ -418,12 +420,10 @@ class Auth(object):
         return Token(token, self.settings.reset_expire)
     
     def sign_in(self, request, user):
-        request.session[AUTH_SESSION_NAME] = get_user_hmac(user)
-        request.user = user
+        self.LazyUser.sign_in(request, user)
     
     def sign_out(self, request):
-        request.session.invalidate()
-        request.user = None
+        self.LazyUser.sign_out(request)
     
     # This method is intended to be called from the command line.
     def create_user(self, login, passw, **data):
